/*
  eagle - controls and limits the programs in execution

  Copyright (C) 2000 <Tullio Dovera tdovera@libero.it>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  Send any bug reports or comments to tdovera@libero.it
*/

#include <string.h>
#include <stdio.h>
#include <stdlib.h>

#include "arg.h"

#define VERSION "0.51"
#define AUTHOR  "Tullio Dovera"
#define MYEMAIL "tdovera@libero.it"
#define WWW     "http://students.silab.dsi.unimi.it/~pd514314/eagle/"
#define NO_WARRANTY "THIS SOFTWARE COMES WITH ABSOLUTELY NO WARRANTY! USE AT YOUR OWN RISK!"

#define DEFAULT_CONFIG_FILE "/etc/eagle.conf"

static char *progname;
static char *configfile;
static int existingprocesses=1; /* 1=mantains existing processes */
static int verbosemode=0;       /* 1=verbose mode */
static int updateseconds=5;     /* default interval in seconds */

char *progName(void) {
  return progname;
}

char *noWarranty(void) {
  return NO_WARRANTY;
}

char *configFile(void) {
  return configfile;
}

int existingProcesses(void) {
  return existingprocesses;
}

int verboseMode(void) {
  return verbosemode;
}

int updateSeconds(void) {
  return updateseconds;
}

void controlArgument(int argc, char **argv) {

  progname = strrchr(argv[0], '/');
  if (progname == NULL)
    progname = argv[0];
  else
    progname++;

  configfile=DEFAULT_CONFIG_FILE;
  
  while (argc > 1 && argv[1][0] == '-') {
    argc--, argv++;
    switch(argv[0][1]) {
    case 'c':
      configfile=malloc(strlen(argv[1])+1);
      strcpy(configfile,argv[1]);
      argc--, argv++;
      break;
    case 'e':
      existingprocesses=0;
      break;
    case 'h':
      usage();
      break;
    case 'u':
      updateseconds=atoi(argv[1]);
      argc--, argv++;
      break;
    case 'v':
      verbosemode=1;
      break;
    case 'V':
      fprintf(stderr,"Version %s\n",VERSION);
      exit(0);
      break;
    default:
      usage();
    }
  }
}

void usage(void)
{
  fprintf(stderr,"Usage: %s [-options]\n", progname);
  fprintf(stderr,"Version %s\n",VERSION);
  fprintf(stderr,"where options include:\n"
          " -help             print out this message\n"
          " -c configFile     Config File\n"
	  " -e                doesn't maintain existing processes\n"
	  "                   BE CAREFULL to use this option. Before read README file\n"
	  " -u seconds        specifies the interval in seconds at which\n"
	  "                   eagle controls the processes (default is 5 second)\n"
	  " -v                verbose mode\n"
	  " -V                print the version number"
          "\n%s\n"
	  "It's distributed under GPL license\n\n",NO_WARRANTY);
  fprintf(stderr,"%s\n",AUTHOR);
  fprintf(stderr,"%s\n",WWW);
  fprintf(stderr,"%s\n\n",MYEMAIL);
  exit(0);
}
